@@ -1,4 +1,4 @@
-/* $Id: sendpacket.c 2024 2008-05-06 19:39:35Z aturner $ */
+/* $Id: sendpacket.c 2059 2008-06-09 19:37:53Z aturner $ */
 
 /*
  * Copyright (c) 2006 Aaron Turner.
@@ -70,16 +70,11 @@
 #include "sendpacket.h"
 
 
-/* Allow users to force the injection method, default is linux PF_PACKET */
-#define INJECT_METHOD "PF_PACKET send()"
-
 #ifdef FORCE_INJECT_LIBNET
 #undef HAVE_PF_PACKET
 #undef HAVE_PCAP_INJECT
 #undef HAVE_PCAP_SENDPACKET
 #undef HAVE_BPF
-#undef INJECT_METHOD
-#define INJECT_METHOD "libnet send()"
 #endif
 
 #ifdef FORCE_INJECT_BPF
@@ -87,8 +82,6 @@
 #undef HAVE_PCAP_INJECT
 #undef HAVE_PCAP_SENDPACKET
 #undef HAVE_PF_PACKET
-#undef INJECT_METHOD
-#define INJECT_METHOD "bpf send()"
 #endif
 
 #ifdef FORCE_INJECT_PCAP_INJECT
@@ -96,8 +89,6 @@
 #undef HAVE_PCAP_SENDPACKET
 #undef HAVE_BPF
 #undef HAVE_PF_PACKET
-#undef INJECT_METHOD
-#define INJECT_METHOD "pcap_inject()"
 #endif
 
 #ifdef FORCE_INJECT_PCAP_SENDPACKET
@@ -105,11 +96,8 @@
 #undef HAVE_PCAP_INJECT
 #undef HAVE_BPF
 #undef HAVE_PF_PACKET
-#undef INJECT_METHOD
-#define INJECT_METHOD "pcap_sendpacket()"
 #endif
 
-
 #if (defined HAVE_WINPCAP && defined HAVE_PCAP_INJECT)
 #undef HAVE_PCAP_INJECT /* configure returns true for some odd reason */
 #endif
@@ -140,6 +128,9 @@
 #include <unistd.h>
 
 #ifdef HAVE_PF_PACKET
+#undef INJECT_METHOD
+#define INJECT_METHOD "PF_PACKET send()"
+
 #include <fcntl.h>
 #include <sys/utsname.h>
 #include <net/if.h>
@@ -159,6 +150,9 @@ static int get_iface_index(int fd, const int8_t *device, char *);
 #endif /* HAVE_PF_PACKET */
 
 #ifdef HAVE_BPF
+#undef INJECT_METHOD
+#define INJECT_METHOD "bpf send()"
+
 #include <net/bpf.h>
 #include <sys/socket.h>
 #include <net/if.h>
@@ -171,6 +165,9 @@ static struct tcpr_ether_addr *sendpacket_get_hwaddr_bpf(sendpacket_t *) _U_;
 #endif /* HAVE_BPF */
 
 #ifdef HAVE_LIBNET
+#undef INJECT_METHOD
+#define INJECT_METHOD "libnet send()"
+
 static sendpacket_t *sendpacket_open_libnet(const char *, char *) _U_;
 static struct tcpr_ether_addr *sendpacket_get_hwaddr_libnet(sendpacket_t *) _U_;
 #endif /* HAVE_LIBNET */
@@ -180,6 +177,14 @@ static sendpacket_t *sendpacket_open_pcap(const char *, char *) _U_;
 static struct tcpr_ether_addr *sendpacket_get_hwaddr_pcap(sendpacket_t *) _U_;
 #endif /* HAVE_PCAP_INJECT || HAVE_PACKET_SENDPACKET */
 
+#ifdef HAVE_PCAP_INJECT
+#undef INJECT_METHOD
+#define INJECT_METHOD "pcap_inject()"
+#elif defined HAVE_PCAP_SENDPACKET
+#undef INJECT_METHOD
+#define INJECT_METHOD "pcap_sendpacket()"
+#endif
+
 static void sendpacket_seterr(sendpacket_t *sp, const char *fmt, ...);
 
 /* You need to define didsig in your main .c file.  Set to 1 if CTRL-C was pressed */
@@ -620,18 +625,10 @@ sendpacket_open_pf(const char *device, char *errbuf)
         return NULL;
     }
 
-#if 0 /* why is this check necessary??? */
-    /* make sure it's ethernet */
-    switch (ifr.ifr_hwaddr.sa_family) {
-        case ARPHRD_ETHER:
-            break;
-        default:
-            snprintf(errbuf, SENDPACKET_ERRBUF_SIZE, 
-                "unsupported pysical layer type 0x%x", ifr.ifr_hwaddr.sa_family);
-            close(mysocket);
-            return NULL;
-    }
-#endif
+    /* make sure it's not loopback (PF_PACKET doesn't support it) */
+    if (ifr.ifr_hwaddr.sa_family != ARPHRD_ETHER)
+        warnx("Unsupported physical layer type 0x%04x on %s.  Maybe it works, maybe it wont."
+        "  See tickets #123/318", ifr.ifr_hwaddr.sa_family, device);
 
 #ifdef SO_BROADCAST
     /*
@@ -644,7 +641,7 @@ sendpacket_open_pf(const char *device, char *errbuf)
      */ 
     if (setsockopt(mysocket, SOL_SOCKET, SO_BROADCAST, &n, sizeof(n)) == -1) {
         snprintf(errbuf, SENDPACKET_ERRBUF_SIZE,
-                "SO_BROADCAS: %s\n", strerror(errno));
+                "SO_BROADCAST: %s\n", strerror(errno));
         close(mysocket);
         return NULL;
     }
